#include <curses.h>
#include <errno.h>
#include <time.h>

/* -----------------------Configure here----------------------- */
/* name of the user data file - this is searched first */
#define HOMEDATAFILENAME        ".hangman.words"
/* name of the default data file */
#define DATAFILENAME    "hangman.words"
/* max length of line of DATAFILENAME */
#define MAXLINELEN	200
/* field delimiter in file DATAFILENAME */
#define DELIMITER	"|"
/* ------------------------------------------------------------ */

/* game variables */
char *word, *suggestion;
int tries;
/******************/

/* dies with the name of the program and
   an error message. return the error
   number */
void die(char *what)
{
   extern char* prog;
   fprintf(stderr, "%s: %s\n", prog, what);
   perror(prog);
   exit(errno);
}

/* standard hack to return the file size;
   don't changes the position
   indicator; another solution is to 
   use the unix call stat(2) */
long filesize(FILE *f)
{
   long size, curpos=ftell(f);
   fseek(f, 0, SEEK_END);
   size=ftell(f);
   fseek(f, curpos, SEEK_SET);
   return size;
}

/* removes a newline at the end of a string
   cannot be used for constant strings */
char *chomp(char *s)
{
   if (s && *s)
   {
      size_t last=strlen(s)-1;
      if (s[last]=='\n')
         s[last]='\0';
   }
   return s;
}

char *my_strtok(char *s, const char *delim)
{
   static char *p;

   for (!s?(s=p):(p=s); !strchr(delim, *p); p++);
   if (*p) *p++='\0';

   return s;
}

void getrandline(char *l, int n)
{
   long size, randpos;
   FILE *f;
   char fname[200];

   /* first try to open $HOME/HOMEDATAFILENAME */
   strcpy(fname, (char *)getenv("HOME"));
   strcat(fname, "/");
   strcat(fname, HOMEDATAFILENAME);
   f=fopen(fname, "r");

   /* if this fails, try to open DATAFILENAME */
   if (f == NULL)
   {
      f=fopen(DATAFILENAME, "r");
      if (f == NULL) die("trying to open " DATAFILENAME);
   }

   size=filesize(f);

   /* init randomizer */
   srand((unsigned)time(NULL));

   do
   {
      /* get a random value in the range [0..size-1] */
      randpos=rand()%size;

      /* seek to a random position in the file - this can be EOF */
      fseek(f, randpos, SEEK_SET);

      fgets(l, n, f);
      /* get line - this can be empty (if we are close to EOF) */
   } while (fgets(l, n, f)==NULL);

   /* close the file */
   fclose(f);
}

void setgamevariable(void)
{
   static char l[MAXLINELEN];

   /* for testing purpose replace this line with
		gets(l); */
   getrandline(l, MAXLINELEN);

   word=chomp(my_strtok(l, DELIMITER));
   suggestion=chomp(my_strtok(NULL, DELIMITER));
   tries=atoi(my_strtok(NULL, DELIMITER));
   if (!tries)
	tries=strlen(word)+1;

   printf("word=%s\nsuggestion=%s\ntries=%d\n", word, suggestion, tries);
}


char *prog;     /* contains the name of the program */

int main(int argc, char *argv[])
{
   prog=argv[0];

   setgamevariable();

   exit(0);
}

